===================
SEAMM MOPAC plug-in
===================

.. image:: https://img.shields.io/github/issues-pr-raw/molssi-seamm/mopac_step
   :target: https://github.com/molssi-seamm/mopac_step/pulls
   :alt: GitHub pull requests

.. image:: https://github.com/molssi-seamm/mopac_step/workflows/CI/badge.svg
   :target: https://github.com/molssi-seamm/mopac_step/actions
   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/mopac_step/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/molssi-seamm/mopac_step
   :alt: Code Coverage

.. image:: https://img.shields.io/lgtm/grade/python/g/molssi-seamm/mopac_step.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/molssi-seamm/mopac_step/context:python
   :alt: Code Quality

.. image:: https://github.com/molssi-seamm/mopac_step/workflows/Documentation/badge.svg
   :target: https://molssi-seamm.github.io/mopac_step/index.html
   :alt: Documentation Status

.. image:: https://pyup.io/repos/github/molssi-seamm/mopac_step/shield.svg
   :target: https://pyup.io/repos/github/molssi-seamm/mopac_step/
   :alt: Updates for Dependencies

.. image:: https://img.shields.io/pypi/v/mopac_step.svg
   :target: https://pypi.python.org/pypi/mopac_step
   :alt: PyPi VERSION

A SEAMM plug-in to setup, run and analyze semiempirical calculations
with MOPAC.

This plug-in provides a graphical user interface (GUI) for setting up
and running simulations using the semiempirical quantum chemistry code
MOPAC_.

* Free software: BSD license
* Documentation: https://molssi-seamm.github.io/mopac_step/index.html
* Code: https://github.com/molssi-seamm/mopac_step

.. _MOPAC: http://openmopac.net

Features
--------

* Single-point energies
* Structural optimization
* IR and Raman vibrational frequencies
* Temperature dependent thermodynamic functions
* Results can be stored in flowchart variables or tables_.

.. _tables: https://molssi-seamm.github.io/table_step/index.html

Acknowledgements
----------------

This package was created with Cookiecutter_ and the `molssi-seamm/cookiecutter-seamm-plugin`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`molssi-seamm/cookiecutter-seamm-plugin`: https://github.com/molssi-seamm/cookiecutter-seamm-plugin

Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the `National Science Foundation`_ under
award ACI-1547580

.. _MolSSI: https://www.molssi.org
.. _`National Science Foundation`: https://www.nsf.gov
